@@ -17,6 +17,7 @@
 
 import copy
 import logging
+import typing as ty
 
 from openstack import exceptions as sdk_exc
 from osc_lib.command import command
@@ -40,6 +41,7 @@ def _format_user(user):
         'name',
         'description',
         'password_expires_at',
+        'options',
     )
     column_headers = (
         'default_project_id',
@@ -50,6 +52,7 @@ def _format_user(user):
         'name',
         'description',
         'password_expires_at',
+        'options',
     )
     return (
         column_headers,
@@ -58,7 +61,7 @@ def _format_user(user):
 
 
 def _get_options_for_user(identity_client, parsed_args):
-    options = {}
+    options: dict[str, ty.Any] = {}
     if parsed_args.ignore_lockout_failure_attempts:
         options['ignore_lockout_failure_attempts'] = True
     if parsed_args.no_ignore_lockout_failure_attempts:
@@ -288,7 +291,7 @@ class CreateUser(command.ShowOne):
         elif parsed_args.password_prompt:
             password = utils.get_password(self.app.stdin)
 
-        if not parsed_args.password:
+        if not password:
             LOG.warning(
                 _(
                     "No password was supplied, authentication will fail "
@@ -377,7 +380,7 @@ class DeleteUser(command.Command):
 
         if errors > 0:
             total = len(parsed_args.users)
-            msg = _("%(errors)s of %(total)s users failed " "to delete.") % {
+            msg = _("%(errors)s of %(total)s users failed to delete.") % {
                 'errors': errors,
                 'total': total,
             }
@@ -411,6 +414,24 @@ class ListUser(command.Lister):
             default=False,
             help=_('List additional fields in output'),
         )
+        parser.add_argument(
+            '--enabled',
+            action='store_true',
+            dest='is_enabled',
+            default=None,
+            help=_(
+                'List only enabled users, does nothing with --project and --group'
+            ),
+        )
+        parser.add_argument(
+            '--disabled',
+            action='store_false',
+            dest='is_enabled',
+            default=None,
+            help=_(
+                'List only disabled users, does nothing with --project and --group'
+            ),
+        )
         return parser
 
     def take_action(self, parsed_args):
@@ -430,6 +451,9 @@ class ListUser(command.Lister):
                 ignore_missing=False,
             ).id
 
+        if parsed_args.is_enabled is not None:
+            enabled = parsed_args.is_enabled
+
         if parsed_args.project:
             if domain is not None:
                 project = identity_client.find_project(
@@ -468,9 +492,15 @@ class ListUser(command.Lister):
                 group=group,
             )
         else:
-            data = identity_client.users(
-                domain_id=domain,
-            )
+            if parsed_args.is_enabled is not None:
+                data = identity_client.users(
+                    domain_id=domain,
+                    is_enabled=enabled,
+                )
+            else:
+                data = identity_client.users(
+                    domain_id=domain,
+                )
 
         # Column handling
         if parsed_args.long:
@@ -612,10 +642,12 @@ class SetUser(command.Command):
         if parsed_args.description:
             kwargs['description'] = parsed_args.description
         if parsed_args.project:
-            project_domain_id = identity_client.find_domain(
-                name_or_id=parsed_args.project_domain,
-                ignore_missing=False,
-            ).id
+            project_domain_id = None
+            if parsed_args.project_domain:
+                project_domain_id = identity_client.find_domain(
+                    name_or_id=parsed_args.project_domain,
+                    ignore_missing=False,
+                ).id
             project_id = identity_client.find_project(
                 name_or_id=parsed_args.project,
                 ignore_missing=False,
@@ -656,6 +688,8 @@ class SetPasswordUser(command.Command):
 
     def take_action(self, parsed_args):
         identity_client = self.app.client_manager.sdk_connection.identity
+        conn = self.app.client_manager.sdk_connection
+        user_id = conn.config.get_auth().get_user_id(conn.identity)
 
         # FIXME(gyee): there are two scenarios:
         #
@@ -698,7 +732,9 @@ class SetPasswordUser(command.Command):
             )
 
         identity_client.update_user(
-            current_password=current_password, password=password
+            user=user_id,
+            current_password=current_password,
+            password=password,
         )
 
 
