@@ -18,6 +18,7 @@
 
 import itertools
 import logging
+import typing as ty
 
 from osc_lib.command import command
 from osc_lib import exceptions
@@ -32,19 +33,18 @@ LOG = logging.getLogger(__name__)
 
 
 def _get_columns(item):
-    column_map = {}
     hidden_columns = ['location', 'tenant_id']
     return utils.get_osc_show_columns_for_sdk_resource(
-        item, column_map, hidden_columns
+        item, {}, hidden_columns
     )
 
 
 def _get_ranges(item):
     item = sorted([int(i) for i in item])
     for a, b in itertools.groupby(enumerate(item), lambda xy: xy[1] - xy[0]):
-        b = list(b)
+        c = list(b)
         yield (
-            f"{b[0][1]}-{b[-1][1]}" if b[0][1] != b[-1][1] else str(b[0][1])
+            f"{c[0][1]}-{c[-1][1]}" if c[0][1] != c[-1][1] else str(c[0][1])
         )
 
 
@@ -59,7 +59,7 @@ def _is_prop_empty(columns, props, prop_name):
 
 
 def _exchange_dict_keys_with_values(orig_dict):
-    updated_dict = dict()
+    updated_dict: dict[str, ty.Any] = {}
     for k, v in orig_dict.items():
         k = [k]
         if not updated_dict.get(v):
@@ -105,8 +105,7 @@ class CreateNetworkSegmentRange(
             dest="private",
             action="store_true",
             help=_(
-                'Network segment range is assigned specifically to the '
-                'project'
+                'Network segment range is assigned specifically to the project'
             ),
         )
         shared_group.add_argument(
@@ -125,7 +124,7 @@ class CreateNetworkSegmentRange(
             metavar='<project>',
             help=_(
                 'Network segment range owner (name or ID). Optional when '
-                'the segment range is shared'
+                'the segment range is shared.'
             ),
         )
         identity_common.add_project_domain_option_to_parser(parser)
@@ -196,8 +195,7 @@ class CreateNetworkSegmentRange(
             and parsed_args.physical_network
         ):
             msg = _(
-                "--physical-network is only allowed with --network-type "
-                "vlan"
+                "--physical-network is only allowed with --network-type vlan"
             )
             raise exceptions.CommandError(msg)
 
@@ -323,7 +321,7 @@ class ListNetworkSegmentRange(command.Lister):
             '--unused',
             action='store_true',
             help=_(
-                'List network segment ranges that have segments ' 'not in use'
+                'List network segment ranges that have segments not in use'
             ),
         )
         available_group = parser.add_mutually_exclusive_group()
@@ -353,10 +351,9 @@ class ListNetworkSegmentRange(command.Lister):
             ) % {'e': e}
             raise exceptions.CommandError(msg)
 
-        filters = {}
-        data = network_client.network_segment_ranges(**filters)
+        data = network_client.network_segment_ranges()
 
-        headers = (
+        headers: tuple[str, ...] = (
             'ID',
             'Name',
             'Default',
@@ -367,7 +364,7 @@ class ListNetworkSegmentRange(command.Lister):
             'Minimum ID',
             'Maximum ID',
         )
-        columns = (
+        columns: tuple[str, ...] = (
             'id',
             'name',
             'default',
@@ -389,16 +386,16 @@ class ListNetworkSegmentRange(command.Lister):
             # should be listed in output.
             parsed_args.long = True
         if parsed_args.long:
-            headers = headers + (
+            headers += (
                 'Used',
                 'Available',
             )
-            columns = columns + (
+            columns += (
                 'used',
                 'available',
             )
 
-        display_props = tuple()
+        display_props: tuple[str, ...] = tuple()
         for s in data:
             props = utils.get_item_properties(s, columns)
             if (
@@ -457,8 +454,7 @@ class SetNetworkSegmentRange(common.NeutronCommandWithExtraArgs):
             )
         except Exception as e:
             msg = _(
-                'Network segment range set not supported by '
-                'Network API: %(e)s'
+                'Network segment range set not supported by Network API: %(e)s'
             ) % {'e': e}
             raise exceptions.CommandError(msg)
 
